@@ -1,4 +1,4 @@
-# Copyright 2013-2020 Reahl Software Services (Pty) Ltd. All rights reserved.
+# Copyright 2013-2022 Reahl Software Services (Pty) Ltd. All rights reserved.
 #
 #    This file is part of Reahl.
 #
@@ -31,7 +31,7 @@ from sqlalchemy.orm import sessionmaker, scoped_session, relationship
 from sqlalchemy.ext.declarative import instrument_declarative, declarative_base, DeclarativeMeta
 from sqlalchemy.exc import InvalidRequestError
 from sqlalchemy import Column, Integer, ForeignKey
-from alembic.migration import MigrationContext
+from alembic.runtime.migration import MigrationContext
 from alembic.operations import Operations
 from alembic.autogenerate import produce_migrations, render_python_code
 
@@ -311,6 +311,7 @@ class SqlAlchemyControl(ORMControl):
             # nested state of the transaction to detect that it is called during a test.
             # If called during a test, this method should NOT commit, and it should NOT
             # nuke the session
+            Session.flush()
             return
 
         self.commit()
